@@ -38,7 +38,7 @@ The C<no_free> flag of the new object is set to 1.
 
 C<method digest : int ($type : L<Net::SSLeay::EVP_MD|SPVM::Net::SSLeay::EVP_MD>, $md : mutable string, $len_ref : int*);>
 
-Calls native L<X509_digest|https://docs.openssl.org/master/man3/X509_digest> function given $type, the pointer value of $md, $len_ref, and returns its return value.
+Calls native L<X509_digest|https://docs.openssl.org/master/man3/X509_digest> function given the pointer value of the instance, $type, the pointer value of $md, $len_ref, and returns its return value.
 
 Exceptions:
 
@@ -54,7 +54,7 @@ If X509_digest failed, an exception is thrown with C<eval_error_id> set to the b
 
 C<method pubkey_digest : int ($type : L<Net::SSLeay::EVP_MD|SPVM::Net::SSLeay::EVP_MD>, $md : mutable string, $len_ref : int*);>
 
-Calls native L<X509_pubkey_digest|https://docs.openssl.org/master/man3/X509_pubkey_digest> function given $type, the pointer value of $md, $len_ref, and returns its return value.
+Calls native L<X509_pubkey_digest|https://docs.openssl.org/master/man3/X509_pubkey_digest> function given the pointer value of the instance, $type, the pointer value of $md, $len_ref, and returns its return value.
 
 Exceptions:
 
@@ -70,13 +70,29 @@ If X509_pubkey_digest failed, an exception is thrown with C<eval_error_id> set t
 
 C<method get_ext_d2i : void ($nid : int, $crit_ref : int*, $idx_ref : int*);>
 
-Calls native L<X509_get_ext_d2i|https://docs.openssl.org/master/man3/X509_pubkey_digest> function given $nid, $crit_ref, $idx_ref.
+Calls native L<X509_get_ext_d2i|https://docs.openssl.org/master/man3/X509_pubkey_digest> function given the pointer value of the instance, $nid, $crit_ref, $idx_ref.
+
+=head2 dup
+
+C<method dup : L<Net::SSLeay::X509|SPVM::Net::SSLeay::X509> ();>
+
+Calls native L<X509_dup|https://docs.openssl.org/3.3/man3/X509_dup> function given the pointer value of the instance, creates a new L<Net::SSLeay::X509|SPVM::Net::SSLeay::X509> object, sets the pointer value of the new object to the return value of the native function, and returns the new object.
+
+=head2 check_issued
+
+C<method check_issued : int ($subject : L<Net::SSLeay::X509|SPVM::Net::SSLeay::X509>);>
+
+Calls native L<X509_check_issued|https://docs.openssl.org/1.1.1/man3/X509_check_issued> function given the pointer value of the instance, the pointer value of $subject, and returns its return value.
+
+Exceptions:
+
+The X509 object $subject must be defined. Otherwise an exception is thrown.
 
 =head2 DESTROY
 
 C<method DESTROY : void ();>
 
-Frees native L<X509|https://docs.openssl.org/3.1/man3/X509_new/> object by calling native L<X509_free|https://docs.openssl.org/3.1/man3/X509_free/> function if C<no_free> flag of the instance is not a true value.
+Calls native L<X509_free|https://docs.openssl.org/3.1/man3/X509_free/> function given the pointer value of the instance if C<no_free> flag of the instance is not a true value.
 
 =head1 FAQ
 
