@@ -13,10 +13,10 @@ int32_t SPVM__Net__SSLeay__X509_CRL__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_self = stack[0].oval;
   
-  X509_CRL* x509_crl = env->get_pointer(env, stack, obj_self);
+  X509_CRL* pointer = env->get_pointer(env, stack, obj_self);
   
   if (!env->no_free(env, stack, obj_self)) {
-    X509_CRL_free(x509_crl);
+    X509_CRL_free(pointer);
   }
   
   return 0;
